# Parselmouth - Praat in Python, the Pythonic way

**Parselmouth** is a Python library for the [Praat](http://www.praat.org)
software.

Though other attempts have been made at porting functionality from Praat to
Python, Parselmouth is unique in its aim to provide a complete and Pythonic
interface to the internal Praat code. While other projects either wrap Praat's
scripting language or reimplementing parts of Praat's functionality in Python,
Parselmouth directly accesses Praat's C/C++ code (which means the algorithms
and their output are exactly the same as in Praat) and provides efficient
access to the program's data, but *also* provides an interface that looks
no different from any other Python library.

Drop by our [Gitter chat room](https://gitter.im/PraatParselmouth/Lobby) or
post a message to our
[Google discussion group](https://groups.google.com/d/forum/parselmouth) if
you have any question, remarks, or requests!

More information on the **installation** and some basic **examples**
can be found on Parselmouth's GitHub repository:
https://github.com/YannickJadoul/Parselmouth
